[![Build Status](https://travis-ci.org/BYU-Hydroinformatics/Hydrostats.svg?branch=master)](https://travis-ci.org/BYU-Hydroinformatics/Hydrostats)
[![codecov](https://codecov.io/gh/BYU-Hydroinformatics/Hydrostats/branch/master/graph/badge.svg)](https://codecov.io/gh/BYU-Hydroinformatics/Hydrostats)

Tools for use in comparison studies, specifically for use in the field of hydrology

- **Documentation:** https://BYU-Hydroinformatics.github.io/Hydrostats/
- **Source:** https://github.com/BYU-Hydroinformatics/Hydrostats
- **Bug reports:** https://github.com/BYU-Hydroinformatics/Hydrostats/issues

Hydrostats provides:

- Preprocessing Tools
- Visualization Tools
- Access to over 70 error metrics through the [HydroErr package](https://github.com/BYU-Hydroinformatics/HydroErr) dependency
- A library of relevant metrics to measure forecast skill

Publications:
- Roberts, W., Williams, G., Jackson, E., Nelson, E., Ames, D., 2018. Hydrostats: A Python Package for Characterizing Errors between Observed and Predicted Time Series. Hydrology 5(4) 66, doi:10.3390/hydrology5040066

We would request that if you use this package that you please cite the above paper. The journal paper is open access and can be found at https://doi.org/10.3390/hydrology5040066. BibTeX, EndNote, and RIS files can be downloaded at the journal site.

[![Powered by BYU Hydroinformatics](https://img.shields.io/badge/powered%20by-BYU%20HydroInformatics-blue.svg)](http://worldwater.byu.edu/)
